/*
 * Decompiled with CFR 0.152.
 */
package com.jiuqi.util.tree;

import com.jiuqi.util.tree.TreeException;

public final class TreeCodeStruct {
    private int structSize;
    private int[] levelLens;
    private int[] levelStarts;

    public TreeCodeStruct(String structStr) throws TreeException {
        if (structStr == null || structStr.length() == 0) {
            this.levelLens = new int[0];
            this.levelStarts = new int[0];
            return;
        }
        String[] lens = structStr.split("[,|;| |\t]+");
        this.levelLens = new int[lens.length];
        this.levelStarts = new int[lens.length];
        this.structSize = 0;
        int i = 0;
        while (i < lens.length) {
            try {
                this.levelLens[i] = Integer.parseInt(lens[i]);
            }
            catch (NumberFormatException e) {
                throw new TreeException("编码结构错误：" + structStr, e);
            }
            this.levelStarts[i] = this.structSize;
            this.structSize += this.levelLens[i];
            ++i;
        }
    }

    public int getStructSize() {
        return this.structSize;
    }

    public int getLevelSize() {
        return this.levelLens == null ? 0 : this.levelLens.length;
    }

    public int getLevelLength(int level) {
        return this.levelLens[level];
    }

    public int getLevelStart(int level) {
        return this.levelStarts[level];
    }

    public boolean emptyLevel(String code, int level) {
        int i = 0;
        while (i < this.levelLens[level]) {
            if (code.length() <= this.levelStarts[level] + i) {
                return true;
            }
            char ch = code.charAt(this.levelStarts[level] + i);
            if (ch != '0' && ch != ' ') {
                return false;
            }
            ++i;
        }
        return true;
    }

    public String shortCode(String code) {
        if (code == null || code.length() == 0) {
            return code;
        }
        int level = this.levelLens.length;
        while (level > 0 && this.emptyLevel(code, level - 1)) {
            --level;
        }
        if (level == 0) {
            return null;
        }
        if (level == this.levelLens.length) {
            return code;
        }
        return code.substring(0, this.levelStarts[level]);
    }

    public String longCode(String code) {
        if (code == null || code.length() == 0) {
            return code;
        }
        if (code.length() == this.structSize) {
            return code;
        }
        if (code.length() < this.structSize) {
            StringBuffer s = new StringBuffer(this.structSize);
            s.append(code);
            int i = code.length();
            while (i < this.structSize) {
                s.append('0');
                ++i;
            }
            return s.toString();
        }
        return code.substring(0, this.structSize);
    }

    public String parentCode(String code) {
        if (this.structSize == 0) {
            return null;
        }
        if (code == null || code.length() == 0) {
            return null;
        }
        int level = this.levelLens.length - 1;
        while (level >= 0 && this.emptyLevel(code, level)) {
            --level;
        }
        if (level <= 0) {
            return null;
        }
        StringBuffer s = new StringBuffer(this.structSize);
        s.append(code.substring(0, this.levelStarts[level]));
        int i = this.levelStarts[level];
        while (i < this.structSize) {
            s.append('0');
            ++i;
        }
        return s.toString();
    }

    public static String shortCode(String structStr, String code) {
        try {
            TreeCodeStruct tcs = new TreeCodeStruct(structStr);
            return tcs.shortCode(code);
        }
        catch (TreeException treeException) {
            return code;
        }
    }

    public static String longCode(String structStr, String code) {
        try {
            TreeCodeStruct tcs = new TreeCodeStruct(structStr);
            return tcs.longCode(code);
        }
        catch (TreeException treeException) {
            return code;
        }
    }

    public static String parentCode(String structStr, String code) {
        try {
            TreeCodeStruct tcs = new TreeCodeStruct(structStr);
            return tcs.parentCode(code);
        }
        catch (TreeException treeException) {
            return null;
        }
    }
}

